"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.pipe = void 0;
function pipe(input, ...operations) {
    let output = input;
    const lazyOperations = operations.map((op) => "lazy" in op ? prepareLazyOperation(op) : undefined);
    let operationIndex = 0;
    while (operationIndex < operations.length) {
        const lazyOperation = lazyOperations[operationIndex];
        if (lazyOperation === undefined || !isIterable(output)) {
            const operation = operations[operationIndex];
            output = operation(output);
            operationIndex += 1;
            continue;
        }
        const lazySequence = [];
        for (let index = operationIndex; index < operations.length; index++) {
            const lazyOp = lazyOperations[index];
            if (lazyOp === undefined) {
                break;
            }
            lazySequence.push(lazyOp);
            if (lazyOp.isSingle) {
                break;
            }
        }
        const accumulator = [];
        const iterator = output[Symbol.iterator]();
        while (true) {
            const result = iterator.next();
            if (result.done ?? false) {
                break;
            }
            const shouldExitEarly = _processItem(result.value, accumulator, lazySequence);
            if (shouldExitEarly) {
                break;
            }
        }
        const { isSingle } = lazySequence[lazySequence.length - 1];
        output = isSingle ? accumulator[0] : accumulator;
        operationIndex += lazySequence.length;
    }
    return output;
}
exports.pipe = pipe;
function _processItem(item, accumulator, lazySequence) {
    if (lazySequence.length === 0) {
        accumulator.push(item);
        return false;
    }
    let currentItem = item;
    let lazyResult = { done: false, hasNext: false };
    let isDone = false;
    for (let operationsIndex = 0; operationsIndex < lazySequence.length; operationsIndex++) {
        const lazyFn = lazySequence[operationsIndex];
        const { index, items } = lazyFn;
        items.push(currentItem);
        lazyResult = lazyFn(currentItem, index, items);
        lazyFn.index += 1;
        if (lazyResult.hasNext) {
            if (lazyResult.hasMany ?? false) {
                for (const subItem of lazyResult.next) {
                    const subResult = _processItem(subItem, accumulator, lazySequence.slice(operationsIndex + 1));
                    if (subResult) {
                        return true;
                    }
                }
                return false;
            }
            currentItem = lazyResult.next;
        }
        if (!lazyResult.hasNext) {
            break;
        }
        if (lazyResult.done) {
            isDone = true;
        }
    }
    if (lazyResult.hasNext) {
        accumulator.push(currentItem);
    }
    if (isDone) {
        return true;
    }
    return false;
}
function prepareLazyOperation(op) {
    const { lazy, lazyArgs } = op;
    const fn = lazy(...(lazyArgs ?? []));
    return Object.assign(fn, {
        isSingle: lazy.single,
        index: 0,
        items: [],
    });
}
function isIterable(something) {
    return (typeof something === "string" ||
        (typeof something === "object" &&
            something !== null &&
            Symbol.iterator in something));
}
